@@ -14,17 +14,19 @@ use 5.005;
 use strict;
 
 BEGIN {
-    $Module::Package::VERSION = '0.20';
+    $Module::Package::VERSION = '0.21';
     $inc::Module::Package::VERSION ||= $Module::Package::VERSION;
     @inc::Module::Package::ISA = __PACKAGE__;
 }
 
 sub import {
     my $class = shift;
-    eval "use inc::Module::Install 1.01 (); 1" or $class->error($@);
+    # Placate a check in Module::Install
+    $INC{'inc/Module/Install.pm'} = __FILE__;
+    eval "use Module::Install 1.01 (); 1" or $class->error($@);
 
     package main;
-    inc::Module::Install->import();
+    Module::Install->import();
     eval {
         module_package_internals_version_check($Module::Package::VERSION);
         module_package_internals_init(@_);
@@ -45,7 +47,13 @@ sub error {
         die <<"...";
 This should not have happened. Hopefully this dump will explain the problem:
 
+inc::Module::Package: $inc::Module::Package::VERSION
+Module::Package: $Module::Package::VERSION
+inc::Module::Install: $inc::Module::Install::VERSION
+Module::Install: $Module::Install::VERSION
+
 Error: $error
+
 %INC:
 $dump1
 \@INC:
